# Changelog

All notable changes in **django-sms** are documented below.

## [Unreleased]

## [0.1.0] (2021-01-15)
### Added
- This `CHANGELOG.md` file to be able to list all notable changes for each version of **django-sms**.

[Unreleased]: https://github.com/roaldnefs/django-sms/compare/v0.1.0...HEAD
[0.1.0]: https://github.com/roaldnefs/django-sms/releases/tag/v0.1.0
